@@ -1089,7 +1089,11 @@ h2o.is_client <- function() get("IS_CLIENT", .pkg.env)
 
 #'
 #' Disable Progress Bar
-#' 
+#'
+#' @param expr When specified, disable progress bar only for the evaluation of the expr and after the evaluation return to the previous setting (default is to show the progress bar), otherwise disable it globally.
+#' @returns Value of expr if specified, otherwise NULL.
+#'
+#' @seealso \link{h2o.show_progress}
 #' @examples
 #' \dontrun{
 #' library(h2o)
@@ -1111,11 +1115,28 @@ h2o.is_client <- function() get("IS_CLIENT", .pkg.env)
 #'                       standardize = FALSE, seed = 1234)
 #' }
 #' @export
-h2o.no_progress <- function() assign("PROGRESS_BAR", FALSE, .pkg.env)
+h2o.no_progress <- function(expr) {
+  if (missing(expr)) {
+    assign("PROGRESS_BAR", FALSE, .pkg.env)
+    invisible(NULL)
+  } else {
+    show_progress <- .h2o.is_progress()
+    if (length(show_progress) == 0L || show_progress) {
+      on.exit(h2o.show_progress())
+    } else {
+      on.exit(h2o.no_progress())
+    }
+    h2o.no_progress()
+    force(expr)
+  }
+}
 
 #'
 #' Enable Progress Bar
+#' @param expr When specified enable progress only for the evaluation of the expr and after the evaluation return to the previous setting (default is to show the progress bar), otherwise enable it globally.
+#' @returns Value of expr if specified, otherwise NULL.
 #'
+#' @seealso \link{h2o.no_progress}
 #' @examples 
 #' \dontrun{
 #' library(h2o)
@@ -1138,7 +1159,21 @@ h2o.no_progress <- function() assign("PROGRESS_BAR", FALSE, .pkg.env)
 #'                       standardize = FALSE, seed = 1234)
 #' }
 #' @export
-h2o.show_progress <- function() assign("PROGRESS_BAR", TRUE, .pkg.env)
+h2o.show_progress <- function(expr) {
+  if (missing(expr)) {
+    assign("PROGRESS_BAR", TRUE, .pkg.env)
+    invisible(NULL)
+  } else {
+    show_progress <- .h2o.is_progress()
+    if (length(show_progress) == 0L || show_progress) {
+      on.exit(h2o.show_progress())
+    } else {
+      on.exit(h2o.no_progress())
+    }
+    h2o.show_progress()
+    force(expr)
+  }
+}
 
 #'
 #' Check if Progress Bar is Enabled
